"""
    Author: Zain Lakhani
    Date: 08/06/2021

    Title: Cloverly Error
    Description: A generic Cloverly Error
"""


class CloverlyError(Exception):
    """A generic Cloverly Error
    """
    pass
